from setuptools import setup

setup(name='passplz',
      version='1.33.77',
      description='A simple password generator',
      url='http://github.com/davoclavo/passplz',
      author='David Gomez Urquiza',
      author_email='d@davo.io',
      license='MIT',
      
      packages=['passplz'],

      test_suite='nose.collector',
      tests_require=['nose', 'nose-cov'],

      scripts=['bin/passplz'],
      )



from uuid import uuid4

def generate_password(password_length = 16):
    random_string = str(uuid4())
    random_password = random_string.replace('-', '')[:password_length]
    return random_password
